#[non_exhaustive]
pub enum Event<'a> { Closed, Done, Title { title: String, }, AppId { app_id: String, }, OutputEnter { output: WlOutput, }, OutputLeave { output: WlOutput, }, WorkspaceEnter { workspace: ZcosmicWorkspaceHandleV1, }, WorkspaceLeave { workspace: ZcosmicWorkspaceHandleV1, }, State { state: Vec<u8>, }, Geometry { output: WlOutput, x: i32, y: i32, width: i32, height: i32, }, ExtWorkspaceEnter { workspace: ExtWorkspaceHandleV1, }, ExtWorkspaceLeave { workspace: ExtWorkspaceHandleV1, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Closed

the toplevel has been closed

The server will emit no further events on the zcosmic_toplevel_handle_v1 after this event. Any requests received aside from the destroy request will be ignored. Upon receiving this event, the client should make the destroy request to allow freeing of resources.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.closed is equivalent.



Done

all information about the toplevel has been sent

This event is sent after all changes in the toplevel state have been sent.

This allows changes to the zcosmic_toplevel_handle_v1 properties to be seen as atomic, even if they happen via multiple events.

Note: this is is not sent after the closed event.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.done is equivalent.



Title

title change

This event is emitted whenever the title of the toplevel changes.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.title is equivalent.

Fields

title: String


AppId

app_id change

This event is emitted whenever the app_id of the toplevel changes.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.app_id is equivalent.

Fields

app_id: String


OutputEnter

toplevel entered an output

This event is emitted whenever the toplevel becomes visible on the given output. A toplevel may be visible on multiple outputs.

Fields

output: WlOutput


OutputLeave

toplevel left an output

This event is emitted whenever the toplevel is no longer visible on a given output. It is guaranteed that an output_enter event with the same output has been emitted before this event.

Fields

output: WlOutput


WorkspaceEnter

toplevel entered an workspace

This event is emitted whenever the toplevel becomes visible on the given workspace. A toplevel may be visible on multiple workspaces.

Fields

workspace: ZcosmicWorkspaceHandleV1


WorkspaceLeave

toplevel left an workspace

This event is emitted whenever the toplevel is no longer visible on a given workspace. It is guaranteed that an workspace_enter event with the same workspace has been emitted before this event.

Fields

workspace: ZcosmicWorkspaceHandleV1


State

the toplevel state changed

This event is emitted once on creation of the zcosmic_toplevel_handle_v1 and again whenever the state of the toplevel changes.

Fields

state: Vec<u8>


Geometry

the toplevel’s position and/or size has changed

Emitted when the geometry of a toplevel (it’s position and/or size) relative to the provided output has changed.

This event is emitted once on creation of the zcosmic_toplevel_handle_v1 for every entered output and again whenever the geometry of the toplevel changes relative to any output.

Only available since version 2 of the interface

Fields

output: WlOutput
x: i32

x coordinate of the upper-left corner

y: i32

y coordinate of the upper-left corner

width: i32

width of the toplevel

height: i32

height of the toplevel



ExtWorkspaceEnter

toplevel entered an workspace

This event is emitted whenever the toplevel becomes visible on the given workspace. A toplevel may be visible on multiple workspaces.

Only available since version 3 of the interface

Fields



ExtWorkspaceLeave

toplevel left an workspace

This event is emitted whenever the toplevel is no longer visible on a given workspace. It is guaranteed that an workspace_enter event with the same workspace has been emitted before this event.

Only available since version 3 of the interface

Fields

Implementations

Source

impl<'a> Event<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message