Struct ZcosmicToplevelHandleV1

pub struct ZcosmicToplevelHandleV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
an open toplevel

A zcosmic_toplevel_handle_v1 object represents an open toplevel window. A single app may have multiple open toplevels.

Each toplevel has a list of outputs it is visible on, exposed to the client via the output_enter and output_leave events.

See also the Request enum for this interface.

Implementations

Source

impl ZcosmicToplevelHandleV1

pub fn closed(&self)

the toplevel has been closed

The server will emit no further events on the zcosmic_toplevel_handle_v1 after this event. Any requests received aside from the destroy request will be ignored. Upon receiving this event, the client should make the destroy request to allow freeing of resources.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.closed is equivalent.

pub fn done(&self)

all information about the toplevel has been sent

This event is sent after all changes in the toplevel state have been sent.

This allows changes to the zcosmic_toplevel_handle_v1 properties to be seen as atomic, even if they happen via multiple events.

Note: this is is not sent after the closed event.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.done is equivalent.

pub fn title(&self, title: String)

title change

This event is emitted whenever the title of the toplevel changes.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.title is equivalent.

pub fn app_id(&self, app_id: String)

app_id change

This event is emitted whenever the app_id of the toplevel changes.

Note: This event will not be emitted for clients binding version 2 of this protocol, as ext_foreign_toplevel_handle_v1.app_id is equivalent.

pub fn output_enter(&self, output: &WlOutput)

toplevel entered an output

This event is emitted whenever the toplevel becomes visible on the given output. A toplevel may be visible on multiple outputs.

pub fn output_leave(&self, output: &WlOutput)

toplevel left an output

This event is emitted whenever the toplevel is no longer visible on a given output. It is guaranteed that an output_enter event with the same output has been emitted before this event.

pub fn workspace_enter(&self, workspace: &ZcosmicWorkspaceHandleV1)

toplevel entered an workspace

This event is emitted whenever the toplevel becomes visible on the given workspace. A toplevel may be visible on multiple workspaces.

pub fn workspace_leave(&self, workspace: &ZcosmicWorkspaceHandleV1)

toplevel left an workspace

This event is emitted whenever the toplevel is no longer visible on a given workspace. It is guaranteed that an workspace_enter event with the same workspace has been emitted before this event.

pub fn state(&self, state: Vec<u8>)

the toplevel state changed

This event is emitted once on creation of the zcosmic_toplevel_handle_v1 and again whenever the state of the toplevel changes.

pub fn geometry( &self, output: &WlOutput, x: i32, y: i32, width: i32, height: i32, )

the toplevel’s position and/or size has changed

Emitted when the geometry of a toplevel (it’s position and/or size) relative to the provided output has changed.

This event is emitted once on creation of the zcosmic_toplevel_handle_v1 for every entered output and again whenever the geometry of the toplevel changes relative to any output.

pub fn ext_workspace_enter(&self, workspace: &ExtWorkspaceHandleV1)

toplevel entered an workspace

This event is emitted whenever the toplevel becomes visible on the given workspace. A toplevel may be visible on multiple workspaces.

pub fn ext_workspace_leave(&self, workspace: &ExtWorkspaceHandleV1)

toplevel left an workspace

This event is emitted whenever the toplevel is no longer visible on a given workspace. It is guaranteed that an workspace_enter event with the same workspace has been emitted before this event.